@@ -10,6 +10,7 @@ from urllib.parse import urlencode
 
 from OpenSSL import SSL
 from twisted.internet import defer, reactor, ssl
+from twisted.internet.protocol import ServerFactory
 from twisted.internet.task import deferLater
 from twisted.names import dns, error
 from twisted.names.server import DNSServerFactory
@@ -95,7 +96,6 @@ class BrokenDownloadResource(resource.Resource):
 
 
 class LeafResource(resource.Resource):
-
     isLeaf = True
 
     def deferRequest(self, request, delay, f, *a, **kw):
@@ -369,6 +369,8 @@ if __name__ == "__main__":
     )
     args = parser.parse_args()
 
+    factory: ServerFactory
+
     if args.type == "http":
         root = Root()
         factory = Site(root)
